@@ -26,7 +26,8 @@
 
 separate_p_footnotes <- function(x) {
   # check inputs ---------------------------------------------------------------
-  if (!inherits(x, "gtsummary") || !"p.value" %in% names(x$table_body))
+  .assert_class(x, "gtsummary")
+  if (!"p.value" %in% names(x$table_body))
     stop("`x=` must be a gtsummary table with a p-value column.", call. = FALSE)
   if (!"stat_test_lbl" %in% names(x$meta_data))
     stop("The `x$meta_data` data frame must have a column called 'stat_test_lbl'.")
