@@ -22,7 +22,8 @@
 #' If type not specified for a variable, the function
 #' will default to an appropriate summary type. See below for details.
 #' @param value List of formulas specifying the value to display for dichotomous
-#' variables.  See below for details.
+#' variables. gtsummary selectors, e.g. `all_dichotomous()`, cannot be used
+#' with this argument. See below for details.
 #' @param statistic List of formulas specifying types of summary statistics to
 #' display for each variable.  The default is
 #' `list(all_continuous() ~ "{median} ({p25}, {p75})", all_categorical() ~ "{n} ({p}%)")`.
@@ -305,41 +306,44 @@ tbl_summary <- function(data, by = NULL, label = NULL, statistic = NULL,
       df_by = df_by(data, by)
     )
 
-  # adding stat footnote
+  # adding "modify_stat_" information ------------------------------------------
+  x$table_styling$header$modify_stat_N <- nrow(data)
+  if (!is.null(by)) {
+    x$table_styling$header <-
+      x$table_styling$header %>%
+      dplyr::left_join(
+        x$df_by %>%
+          select(column = .data$by_col,
+                 modify_stat_n = .data$n,
+                 modify_stat_p = .data$p,
+                 modify_stat_level = .data$by_chr),
+        by = "column"
+      )
+  }
+
+  # adding headers and footnote ------------------------------------------------
   x <-
     modify_table_styling(
       x,
-      columns = starts_with("stat_"),
+      columns = all_stat_cols(),
       footnote = footnote_stat_label(meta_data)
+    ) %>%
+    modify_header(
+      label = paste0("**", translate_text("Characteristic"), "**"),
+      all_stat_cols() ~
+        ifelse(is.null(by),
+               "**N = {style_number(N)}**",
+               "**{level}**, N = {style_number(n)}")
     )
 
-  # returning all results in a list --------------------------------------------
-  # assigning a class of tbl_summary (for special printing in Rmarkdown)
+  # assign class and return final tbl ------------------------------------------
   class(x) <- c("tbl_summary", class(x))
 
-  # adding headers
-  if (is.null(by)) {
-    x <- modify_header(
-      x,
-      stat_0 = "**N = {style_number(N)}**",
-      label = paste0("**", translate_text("Characteristic"), "**")
-    )
-  } else {
-    x <- modify_header(
-      x,
-      update = list(
-        all_stat_cols(FALSE) ~ "**{level}**, N = {style_number(n)}",
-        label ~ paste0("**", translate_text("Characteristic"), "**")
-      )
-    )
-  }
-
-  # running any additional mods ------------------------------------------------
+  # running any additional mods
   x <-
     get_theme_element("tbl_summary-fn:addnl-fn-to-run", default = identity) %>%
     do.call(list(x))
 
-  # returning tbl_summary table ------------------------------------------------
   x
 }
 
@@ -367,14 +371,15 @@ generate_metadata <- function(data, value, by, type, label,
   # updating type --------------------------------------------------------------
   # updating type of user supplied one
   # converting tidyselect formula lists to named lists
-  type <- .formula_list_to_named_list(
-    x = type,
-    data = data,
-    var_info = meta_data_to_var_info(meta_data),
-    arg_name = "type",
-    type_check = chuck(type_check, "is_string", "fn"),
-    type_check_msg = chuck(type_check, "is_string", "msg")
-  )
+  type <-
+    .formula_list_to_named_list(
+      x = type,
+      data = data,
+      var_info = meta_data_to_var_info(meta_data),
+      arg_name = "type",
+      type_check = chuck(type_check, "is_string_summary_type", "fn"),
+      type_check_msg = chuck(type_check, "is_string_summary_type", "msg")
+    )
 
   # updating meta data object with new types
   meta_data <-
@@ -416,8 +421,8 @@ generate_metadata <- function(data, value, by, type, label,
     data = data,
     var_info = meta_data_to_var_info(meta_data),
     arg_name = "sort",
-    type_check = chuck(type_check, "is_string", "fn"),
-    type_check_msg = chuck(type_check, "is_string", "msg")
+    type_check = chuck(type_check, "is_string_summary_sort", "fn"),
+    type_check_msg = chuck(type_check, "is_string_summary_sort", "msg")
   )
 
   # assigning variable characteristics -----------------------------------------
