@@ -513,243 +513,13 @@ tbl_summary_input_checks <- function(data, by, label, type, value, statistic,
   tbl_summary_data_checks(data)
   check_haven_labelled(data)
 
-  # by -------------------------------------------------------------------------
-  if (!is.null(by) && !by %in% names(data)) {
-    stop(glue(
-      "`by = '{by}'` is not a column in `data=`. Did you misspell the column name, ",
-      "or omit the column with the `include=` argument?"
-    ), call. = FALSE)
-  }
-
-  # type -----------------------------------------------------------------------
-  if (!is.null(type) & is.null(names(type))) { # checking names for deprecated named list input
-
-    # checking input type: must be a list of formulas, or one formula
-    if (!inherits(type, c("list", "formula"))) {
-      stop(glue(
-        "'type' argument must be a list of formulas or named list (see `?syntax`). ",
-        "LHS of the formula is the variable specification, ",
-        "and the RHS is the type specification: ",
-        "list(c(age, marker) ~ \"continuous\")"
-      ), call. = FALSE)
-    }
-    if (inherits(type, "list")) {
-      if (some(type, negate(rlang::is_bare_formula))) {
-        stop(glue(
-          "'type' argument must be a list of formulas or named list (see `?syntax`). ",
-          "LHS of the formula is the variable specification, ",
-          "and the RHS is the type specification: ",
-          "list(c(age, marker) ~ \"continuous\")"
-        ), call. = FALSE)
-      }
-    }
-
-    # all specified types are continuous, categorical, or dichotomous
-    if (inherits(type, "formula")) type <- list(type)
-    if (!every(type, ~ eval_rhs(.x) %in% c(
-      "continuous", "continuous2",
-      "categorical", "dichotomous"
-    )) |
-      !every(type, ~ rlang::is_string(eval_rhs(.x)))) {
-      stop(glue(
-        "The RHS of the formula in the 'type'  argument must of one and only one of ",
-        "\"continuous\", \"continuous2\", \"categorical\", or \"dichotomous\""
-      ), call. = FALSE)
-    }
-  }
-
-  # value ----------------------------------------------------------------------
-  if (!is.null(value) & is.null(names(value))) { # checking names for deprecated named list input
-
-    # checking input type: must be a list of formulas, or one formula
-    if (!inherits(value, c("list", "formula"))) {
-      stop(glue(
-        "'value' argument must be a list of formulas or named list (see `?syntax`). ",
-        "LHS of the formula is the variable specification, ",
-        "and the RHS is the value specification: ",
-        "list(stage ~ \"T1\")"
-      ), call. = FALSE)
-    }
-    if (inherits(value, "list")) {
-      if (some(value, negate(rlang::is_bare_formula))) {
-        stop(glue(
-          "'value' argument must be a list of formulas or named list (see `?syntax`). ",
-          "LHS of the formula is the variable specification, ",
-          "and the RHS is the value specification: ",
-          "list(stage ~ \"T1\")"
-        ), call. = FALSE)
-      }
-    }
-
-    # functions all_continuous, all_categorical, and all_dichotomous cannot be used for value
-    if (some(
-      value,
-      ~ deparse(.x) %>% # converts a formula to a string
-        stringr::str_detect(c("all_continuous()", "all_categorical()", "all_dichotomous()")) %>%
-        any()
-    )) {
-      stop(glue(
-        "Select functions all_continuous(), all_categorical(), all_dichotomous() ",
-        "cannot be used in the 'value' argument."
-      ), call. = FALSE)
-    }
-  }
-
-  # label ----------------------------------------------------------------------
-  if (!is.null(label) & is.null(names(label))) { # checking names for deprecated named list input
-
-    # all specified labels must be a string of length 1
-    if (inherits(label, "formula")) label <- list(label)
-    if (!every(label, ~ rlang::is_string(eval_rhs(.x)))) {
-      stop(glue(
-        "The RHS of the formula in the 'label' argument must be a string."
-      ), call. = FALSE)
-    }
-  }
-
-  # statistic ------------------------------------------------------------------
-  if (!is.null(statistic) & is.null(names(statistic))) { # checking names for deprecated named list input
-
-    # checking input type: must be a list of formulas, or one formula
-    if (!inherits(statistic, c("list", "formula"))) {
-      stop(glue(
-        "'statistic' argument must be a list of formulas or named list (see `?syntax`). ",
-        "LHS of the formula is the variable specification, ",
-        "and the RHS is the statistic specification: ",
-        "list(all_categorical() ~ \"{n} / {N}\")"
-      ), call. = FALSE)
-    }
-    if (inherits(statistic, "list")) {
-      if (some(statistic, negate(rlang::is_bare_formula))) {
-        stop(glue(
-          "'statistic' argument must be a list of formulas or named list (see `?syntax`). ",
-          "LHS of the formula is the variable specification, ",
-          "and the RHS is the statistic specification: ",
-          "list(all_categorical() ~ \"{n} / {N}\")"
-        ), call. = FALSE)
-      }
-    }
-
-    # all specified statistics must be a string of length 1
-    if (inherits(statistic, "formula")) statistic <- list(statistic)
-    if (!every(statistic, ~ rlang::is_character(eval_rhs(.x)))) {
-      stop(glue(
-        "The RHS of the formula in the 'statistic' argument must be a string."
-      ), call. = FALSE)
-    }
-  }
-
-  # digits ---------------------------------------------------------------------
-  if (!is.null(digits) & is.null(names(digits))) { # checking names for deprecated named list input
-
-    # checking input type: must be a list of formulas, or one formula
-    if (!inherits(digits, c("list", "formula"))) {
-      stop(glue(
-        "'digits' argument must be a list of formulas or named list (see `?syntax`). ",
-        "LHS of the formula is the variable specification, ",
-        "and the RHS is the digits specification: ",
-        "list(c(age, marker) ~ 1)"
-      ), call. = FALSE)
-    }
-    if (inherits(digits, "list")) {
-      if (some(digits, negate(rlang::is_bare_formula))) {
-        stop(glue(
-          "'digits' argument must be a list of formulas or named list (see `?syntax`). ",
-          "LHS of the formula is the variable specification, ",
-          "and the RHS is the digits specification: ",
-          "list(c(age, marker) ~ 1)"
-        ), call. = FALSE)
-      }
-    }
-  }
-
   # missing_text ---------------------------------------------------------------
   # input must be character
   if (!rlang::is_string(missing_text)) {
     stop("Argument 'missing_text' must be a character string of length 1.", call. = FALSE)
   }
-
-  # sort -----------------------------------------------------------------------
-  if (!is.null(sort) & is.null(names(sort))) { # checking names for deprecated named list input
-
-    # checking input type: must be a list of formulas, or one formula
-    if (!inherits(sort, c("list", "formula"))) {
-      stop(glue(
-        "'sort' argument must be a list of formulas or named list (see `?syntax`). ",
-        "LHS of the formula is the variable specification, ",
-        "and the RHS is the sort specification: ",
-        "list(c(stage, marker) ~ \"frequency\")"
-      ), call. = FALSE)
-    }
-    if (inherits(sort, "list")) {
-      if (some(sort, negate(rlang::is_bare_formula))) {
-        stop(glue(
-          "'sort' argument must be a list of formulas or named list (see `?syntax`). ",
-          "LHS of the formula is the variable specification, ",
-          "and the RHS is the sort specification: ",
-          "list(c(stage, marker) ~ \"frequency\")"
-        ), call. = FALSE)
-      }
-    }
-
-    # all sepcifed types are frequency or alphanumeric
-    if (inherits(sort, "formula")) sort <- list(sort)
-    if (!every(sort, ~ eval_rhs(.x) %in% c("frequency", "alphanumeric")) |
-      !every(sort, ~ rlang::is_string(eval_rhs(.x)))) {
-      stop(glue(
-        "The RHS of the formula in the 'sort' argument must of one and only one of ",
-        "\"frequency\" or \"alphanumeric\""
-      ), call. = FALSE)
-    }
-  }
 }
 
-# # data
-#   # not putting in a data frame
-#   tbl_summary_input_checks(
-#     data = list(not = "a", proper = "data.frame"), by = NULL, summary_type = NULL, var_label = NULL,
-#     stat_display = NULL, digits = NULL, pvalue_fun = NULL
-#   )
-#
-# # by
-#   # by var not in dataset
-#   tbl_summary_input_checks(
-#     data = mtcars, by = "Petal.Width", summary_type = NULL, var_label = NULL,
-#     stat_display = NULL, digits = NULL, pvalue_fun = NULL
-#   )
-#
-# # summary_type
-#   # names not a variables name, and input type not valid
-#   tbl_summary_input_checks(
-#     data = mtcars, by = NULL, summary_type = list(hp = "continuous", length = "catttegorical"), var_label = NULL,
-#     stat_display = NULL, digits = NULL, pvalue_fun = NULL
-#   )
-#
-# # var_label
-#   # names not a variables name, and input type not valid
-#   tbl_summary_input_checks(
-#     data = mtcars, by = NULL, summary_type = NULL, var_label = list(hp = "Horsepower", wrong_name = "Not a variable"),
-#     stat_display = NULL, digits = NULL, pvalue_fun = NULL
-#   )
-#
-# # stat_display
-#   tbl_summary_input_checks(
-#     data = mtcars, by = NULL, summary_type = NULL, var_label = NULL,
-#     stat_display = list(continuous = "{mean}", dichot_not = "nope"), digits = NULL, pvalue_fun = NULL
-#   )
-#
-# # digits
-#   tbl_summary_input_checks(
-#     data = mtcars, by = NULL, summary_type = NULL, var_label = NULL,
-#     stat_display = NULL, digits = list(hp = 2, wrong_name = 2.1, am = 5.4), pvalue_fun = NULL
-#   )
-
-# tbl_summary_input_checks(
-#   data = NULL, by = NULL, summary_type = NULL, var_label = NULL,
-#   stat_display = NULL, digits = NULL, pvalue_fun = NULL
-# )
-
-
 # stat_label_match -------------------------------------------------------------
 # provide a vector of stat_display and get labels back i.e. {mean} ({sd}) gives Mean (SD)
 stat_label_match <- function(stat_display, iqr = TRUE, range = TRUE) {
@@ -1119,7 +889,7 @@ adding_formatting_as_attr <- function(df_stats, data, variable, summary_type,
   # setting the default formatting ---------------------------------------------
   percent_fun <-
     get_theme_element("tbl_summary-fn:percent_fun") %||%
-    getOption("gtsummary.tbl_summary.percent_fun", default = style_percent)
+    .get_deprecated_option("gtsummary.tbl_summary.percent_fun", default = style_percent)
 
   # extracting statistics requested
   fns_names_chr <-
@@ -1151,7 +921,7 @@ adding_formatting_as_attr <- function(df_stats, data, variable, summary_type,
         ~ switch(is.numeric(.x) & .y %in% percent_stats,
           purrr::partial(style_number, digits = !!.x, scale = 100)
         ) %||%
-          switch(is.numeric(.x) & summary_type %in% c("categorical", "dichotomous") & .y %in% "p",
+          switch(is.numeric(.x) & summary_type %in% c("categorical", "dichotomous") & .y %in% c("p", "p_unweighted"),
             purrr::partial(style_number, digits = !!.x, scale = 100)
           ) %||%
           # all other stats are not scaled
@@ -1198,7 +968,7 @@ adding_formatting_as_attr <- function(df_stats, data, variable, summary_type,
         }
 
         # if the variable is categorical and a percent, use `style_percent`
-        else if (summary_type %in% c("categorical", "dichotomous") & colname %in% "p") {
+        else if (summary_type %in% c("categorical", "dichotomous") & colname %in% c("p", "p_unweighted")) {
           attr(column, "fmt_fun") <- percent_fun
         }
 
